# Security Policy

## Supported Versions

OWS does not currently issue special security updates.  Security updates are
included in the normal release cycle.

## Reporting a Vulnerability

Security vulnerabilities can be reported as regular Github issues. If there
are concerns about early public disclosure, security vulnerabilities can be
reported to Paul Haesler, either by direct message on the opendatacube Slack, or
by email to `paul (dot) haesler (at) ga (dot) gov (dot) au`.
